@@ -279,7 +279,7 @@ async fn handle_event(index: usize, node: &mut Routing, event: Event) -> bool {
             info!("Node #{} requires restart", index);
             return false;
         }
-        Event::ClientMessageReceived { msg, user, .. } => info!(
+        Event::ClientMsgReceived { msg, user, .. } => info!(
             "Node #{} received message from user: {:?}, msg: {:?}",
             index, user, msg
         ),
@@ -288,12 +288,10 @@ async fn handle_event(index: usize, node: &mut Routing, event: Event) -> bool {
             remaining,
             added,
             removed,
-        } => {
-            info!(
-                "Node #{} adults changed - remaining: {:?}, added: {:?}, removed: {:?}",
-                index, remaining, added, removed
-            )
-        }
+        } => info!(
+            "Node #{} adults changed - remaining: {:?}, added: {:?}, removed: {:?}",
+            index, remaining, added, removed
+        ),
     }
 
     true
