@@ -13,7 +13,6 @@ use futures::stream::{FuturesUnordered, StreamExt};
 use hex_fmt::HexFmt;
 use qp2p::{Endpoint, QuicP2p};
 use sn_messaging::MessageType;
-use std::net::IpAddr;
 use std::{
     fmt::{self, Debug, Formatter},
     net::SocketAddr,
@@ -115,10 +114,6 @@ impl Comm {
         self.endpoint.socket_addr()
     }
 
-    pub(crate) fn local_addr(&self) -> SocketAddr {
-        self.endpoint.local_addr()
-    }
-
     /// Sends a message on an existing connection. If no such connection exists, returns an error.
     pub async fn send_on_existing_connection(
         &self,
@@ -141,7 +136,30 @@ impl Comm {
 
     /// Tests whether the peer is reachable.
     pub async fn is_reachable(&self, peer: &SocketAddr) -> Result<(), Error> {
-        is_reachable(self.endpoint.local_addr().ip(), peer).await
+        let qp2p_config = qp2p::Config {
+            local_ip: Some(self.endpoint.local_addr().ip()),
+            local_port: Some(0),
+            forward_port: false,
+            ..Default::default()
+        };
+
+        let qp2p = QuicP2p::with_config(Some(qp2p_config), &[], false)
+            .map_err(|err| Error::InvalidConfig { err })?;
+        let (connectivity_endpoint, _, _, _) = qp2p
+            .new_endpoint()
+            .await
+            .map_err(|err| Error::CannotConnectEndpoint { err })?;
+
+        connectivity_endpoint
+            .is_reachable(peer)
+            .await
+            .map_err(|err| {
+                info!("Peer {} is NOT externally reachable: {}", peer, err);
+                Error::AddressNotReachable { err }
+            })
+            .map(|()| {
+                info!("Peer {} is externally reachable.", peer);
+            })
     }
 
     /// Sends a message to multiple recipients. Attempts to send to `delivery_group_size`
@@ -278,33 +296,6 @@ impl Comm {
     }
 }
 
-pub(crate) async fn is_reachable(our_local_ip: IpAddr, peer: &SocketAddr) -> Result<()> {
-    let qp2p_config = qp2p::Config {
-        local_ip: Some(our_local_ip),
-        local_port: Some(0),
-        forward_port: false,
-        ..Default::default()
-    };
-
-    let qp2p = QuicP2p::with_config(Some(qp2p_config), &[], false)
-        .map_err(|err| Error::InvalidConfig { err })?;
-    let (connectivity_endpoint, _, _, _) = qp2p
-        .new_endpoint()
-        .await
-        .map_err(|err| Error::CannotConnectEndpoint { err })?;
-
-    connectivity_endpoint
-        .is_reachable(peer)
-        .await
-        .map_err(|err| {
-            info!("Peer {} is NOT externally reachable: {}", peer, err);
-            Error::AddressNotReachable { err }
-        })
-        .map(|()| {
-            info!("Peer {} is externally reachable.", peer);
-        })
-}
-
 impl Drop for Comm {
     fn drop(&mut self) {
         self.endpoint.close()
@@ -361,7 +352,7 @@ mod tests {
     use futures::future;
     use qp2p::Config;
     use sn_data_types::PublicKey;
-    use sn_messaging::{section_info::Message, DestInfo, WireMsg};
+    use sn_messaging::{section_info::SectionInfoMsg, DestInfo, WireMsg};
     use std::{net::Ipv4Addr, slice, time::Duration};
     use tokio::{net::UdpSocket, sync::mpsc, time};
 
@@ -543,10 +534,7 @@ mod tests {
         // Send the first message.
         let key0 = bls::SecretKey::random().public_key();
         let msg0 = MessageType::SectionInfo {
-            msg: Message::GetSectionQuery {
-                public_key: PublicKey::Bls(key0),
-                is_node: true,
-            },
+            msg: SectionInfoMsg::GetSectionQuery(PublicKey::Bls(key0)),
             dest_info: DestInfo {
                 dest: name,
                 dest_section_pk: key0,
@@ -571,10 +559,7 @@ mod tests {
         // Send the second message.
         let key1 = bls::SecretKey::random().public_key();
         let msg1 = MessageType::SectionInfo {
-            msg: Message::GetSectionQuery {
-                public_key: PublicKey::Bls(key1),
-                is_node: true,
-            },
+            msg: SectionInfoMsg::GetSectionQuery(PublicKey::Bls(key1)),
             dest_info: DestInfo {
                 dest: name,
                 dest_section_pk: key1,
@@ -637,10 +622,7 @@ mod tests {
     fn new_section_info_message() -> MessageType {
         let random_bls_pk = bls::SecretKey::random().public_key();
         MessageType::SectionInfo {
-            msg: Message::GetSectionQuery {
-                public_key: PublicKey::Bls(random_bls_pk),
-                is_node: true,
-            },
+            msg: SectionInfoMsg::GetSectionQuery(PublicKey::Bls(random_bls_pk)),
             dest_info: DestInfo {
                 dest: XorName::random(),
                 dest_section_pk: bls::SecretKey::random().public_key(),
